@@ -27,7 +27,15 @@ from .progress import NullProgressReporter, ProgressReporter
 
 def _input_to_output_filename(filename: Path, small: bool = False) -> Path:
     dot_index = filename.name.rfind(".")
-    suffix = "_speedup_small" if small else "_speedup"
+    suffix_parts = []
+
+    if small:
+        suffix_parts.append("_small")
+
+    if not suffix_parts:
+        suffix_parts.append("")  # Default case
+
+    suffix = "_speedup" + "".join(suffix_parts)
     new_name = (
         filename.name[:dot_index] + suffix + filename.name[dot_index:]
         if dot_index != -1
@@ -38,7 +46,7 @@ def _input_to_output_filename(filename: Path, small: bool = False) -> Path:
 
 def _create_path(path: Path) -> None:
     try:
-        path.mkdir()
+        path.mkdir(parents=True, exist_ok=True)
     except OSError as exc:  # pragma: no cover - defensive logging
         raise AssertionError(
             "Creation of the directory failed. (The TEMP folder may already exist. Delete or rename it, and try again.)"
@@ -74,7 +82,7 @@ def _extract_video_metadata(input_file: Path, frame_rate: float) -> Dict[str, fl
         "-select_streams",
         "v",
         "-show_entries",
-        "format=duration:stream=avg_frame_rate",
+        "format=duration:stream=avg_frame_rate,nb_frames",
     ]
     process = subprocess.Popen(
         command,
@@ -92,7 +100,14 @@ def _extract_video_metadata(input_file: Path, frame_rate: float) -> Dict[str, fl
     match_duration = re.search(r"duration=([\d.]*)", str(stdout))
     original_duration = float(match_duration.group(1)) if match_duration else 0.0
 
-    return {"frame_rate": frame_rate, "duration": original_duration}
+    match_frames = re.search(r"nb_frames=(\d+)", str(stdout))
+    frame_count = int(match_frames.group(1)) if match_frames else 0
+
+    return {
+        "frame_rate": frame_rate,
+        "duration": original_duration,
+        "frame_count": frame_count,
+    }
 
 
 def _ensure_two_dimensional(audio_data: np.ndarray) -> np.ndarray:
@@ -135,6 +150,18 @@ def speed_up_video(
     metadata = _extract_video_metadata(input_path, options.frame_rate)
     frame_rate = metadata["frame_rate"]
     original_duration = metadata["duration"]
+    frame_count = metadata.get("frame_count", 0)
+
+    reporter.log(
+        (
+            "Source metadata — duration: {duration:.2f}s, frame rate: {fps:.3f} fps,"
+            " reported frames: {frames}"
+        ).format(
+            duration=original_duration,
+            fps=frame_rate,
+            frames=frame_count if frame_count > 0 else "unknown",
+        )
+    )
 
     reporter.log("Processing on: {}".format("GPU (CUDA)" if cuda_available else "CPU"))
     if options.small:
@@ -148,10 +175,12 @@ def speed_up_video(
     audio_bitrate = "128k" if options.small else "160k"
     audio_wav = temp_path / "audio.wav"
 
+    extraction_sample_rate = options.sample_rate
+
     extract_command = build_extract_audio_command(
         os.fspath(input_path),
         os.fspath(audio_wav),
-        options.sample_rate,
+        extraction_sample_rate,
         audio_bitrate,
         hwaccel,
         ffmpeg_path=ffmpeg_path,
@@ -159,10 +188,19 @@ def speed_up_video(
 
     reporter.log("Extracting audio...")
     process_callback = getattr(reporter, "process_callback", None)
+    estimated_total_frames = frame_count
+    if estimated_total_frames <= 0 and original_duration > 0 and frame_rate > 0:
+        estimated_total_frames = int(math.ceil(original_duration * frame_rate))
+
+    if estimated_total_frames > 0:
+        reporter.log(f"Extract audio target frames: {estimated_total_frames}")
+    else:
+        reporter.log("Extract audio target frames: unknown")
+
     run_timed_ffmpeg_command(
         extract_command,
         reporter=reporter,
-        total=int(original_duration * frame_rate),
+        total=estimated_total_frames if estimated_total_frames > 0 else None,
         unit="frames",
         desc="Extracting audio:",
         process_callback=process_callback,
@@ -173,7 +211,7 @@ def speed_up_video(
     audio_sample_count = audio_data.shape[0]
     max_audio_volume = audio_utils.get_max_volume(audio_data)
 
-    reporter.log("\nProcessing Information:")
+    reporter.log("\nInformation:")
     reporter.log(f"- Max Audio Volume: {max_audio_volume}")
 
     samples_per_frame = wav_sample_rate / frame_rate
@@ -202,9 +240,11 @@ def speed_up_video(
     )
 
     audio_new_path = temp_path / "audioNew.wav"
+    # Use the sample rate that was actually used for processing
+    output_sample_rate = extraction_sample_rate
     wavfile.write(
         os.fspath(audio_new_path),
-        options.sample_rate,
+        output_sample_rate,
         _prepare_output_audio(output_audio_data),
     )
 
@@ -246,10 +286,29 @@ def speed_up_video(
         raise FileNotFoundError("Filter graph file was not generated")
 
     try:
+        final_total_frames = updated_chunks[-1][3] if updated_chunks else 0
+        if final_total_frames > 0:
+            reporter.log(f"Final encode target frames: {final_total_frames}")
+            if frame_rate > 0:
+                final_duration_seconds = final_total_frames / frame_rate
+                reporter.log(
+                    (
+                        "Final encode target duration: {duration:.2f}s at {fps:.3f} fps"
+                    ).format(duration=final_duration_seconds, fps=frame_rate)
+                )
+            else:
+                reporter.log(
+                    "Final encode target duration: unknown (missing frame rate)"
+                )
+        else:
+            reporter.log("Final encode target frames: unknown")
+
+        total_frames_arg = final_total_frames if final_total_frames > 0 else None
+
         run_timed_ffmpeg_command(
             command_str,
             reporter=reporter,
-            total=updated_chunks[-1][3],
+            total=total_frames_arg,
             unit="frames",
             desc="Generating final:",
             process_callback=process_callback,
@@ -257,10 +316,25 @@ def speed_up_video(
     except subprocess.CalledProcessError as exc:
         if fallback_command_str and use_cuda_encoder:
             reporter.log("CUDA encoding failed, retrying with CPU encoder...")
+            if final_total_frames > 0:
+                reporter.log(
+                    f"Final encode target frames (fallback): {final_total_frames}"
+                )
+            else:
+                reporter.log("Final encode target frames (fallback): unknown")
+            if final_total_frames > 0 and frame_rate > 0:
+                reporter.log(
+                    (
+                        "Final encode target duration (fallback): {duration:.2f}s at {fps:.3f} fps"
+                    ).format(
+                        duration=final_total_frames / frame_rate,
+                        fps=frame_rate,
+                    )
+                )
             run_timed_ffmpeg_command(
                 fallback_command_str,
                 reporter=reporter,
-                total=updated_chunks[-1][3],
+                total=total_frames_arg,
                 unit="frames",
                 desc="Generating final (fallback):",
                 process_callback=process_callback,
